/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.prediction.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;

/**
 * Model definition for Analyze.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Prediction API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Analyze extends GenericJson {

  /**
   * Description of the data the model was trained on.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DataDescription dataDescription;

  /**
   * List of errors with the data.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<java.util.Map<String, String>> errors;

  /**
   * The unique name for the predictive model.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * What kind of resource this is.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Description of the model.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ModelDescription modelDescription;

  /**
   * A URL to re-request this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * Description of the data the model was trained on.
   * The value returned may be {@code null}.
   */
  public DataDescription getDataDescription() {
    return dataDescription;
  }

  /**
   * Description of the data the model was trained on.
   * The value set may be {@code null}.
   */
  public Analyze setDataDescription(DataDescription dataDescription) {
    this.dataDescription = dataDescription;
    return this;
  }

  /**
   * List of errors with the data.
   * The value returned may be {@code null}.
   */
  public java.util.List<java.util.Map<String, String>> getErrors() {
    return errors;
  }

  /**
   * List of errors with the data.
   * The value set may be {@code null}.
   */
  public Analyze setErrors(java.util.List<java.util.Map<String, String>> errors) {
    this.errors = errors;
    return this;
  }

  /**
   * The unique name for the predictive model.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The unique name for the predictive model.
   * The value set may be {@code null}.
   */
  public Analyze setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * What kind of resource this is.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * What kind of resource this is.
   * The value set may be {@code null}.
   */
  public Analyze setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Description of the model.
   * The value returned may be {@code null}.
   */
  public ModelDescription getModelDescription() {
    return modelDescription;
  }

  /**
   * Description of the model.
   * The value set may be {@code null}.
   */
  public Analyze setModelDescription(ModelDescription modelDescription) {
    this.modelDescription = modelDescription;
    return this;
  }

  /**
   * A URL to re-request this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * A URL to re-request this resource.
   * The value set may be {@code null}.
   */
  public Analyze setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Description of the data the model was trained on.
   */
  public static final class DataDescription extends GenericJson {

    /**
     * Description of the input features in the data set.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.List<Features> features;

    static {
      // hack to force ProGuard to consider Features used, since otherwise it would be stripped out
      // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
      com.google.api.client.util.Data.nullOf(Features.class);
    }

    /**
     * Description of the output value or label.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private OutputFeature outputFeature;

    /**
     * Description of the input features in the data set.
     * The value returned may be {@code null}.
     */
    public java.util.List<Features> getFeatures() {
      return features;
    }

    /**
     * Description of the input features in the data set.
     * The value set may be {@code null}.
     */
    public DataDescription setFeatures(java.util.List<Features> features) {
      this.features = features;
      return this;
    }

    /**
     * Description of the output value or label.
     * The value returned may be {@code null}.
     */
    public OutputFeature getOutputFeature() {
      return outputFeature;
    }

    /**
     * Description of the output value or label.
     * The value set may be {@code null}.
     */
    public DataDescription setOutputFeature(OutputFeature outputFeature) {
      this.outputFeature = outputFeature;
      return this;
    }

    /**
     * Model definition for AnalyzeDataDescriptionFeatures.
     */
    public static final class Features extends GenericJson {

      /**
       * Description of the categorical values of this feature.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Categorical categorical;

      /**
       * The feature index.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key @JsonString
      private Long index;

      /**
       * Description of the numeric values of this feature.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Numeric numeric;

      /**
       * Description of multiple-word text values of this feature.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Text text;

      /**
       * Description of the categorical values of this feature.
       * The value returned may be {@code null}.
       */
      public Categorical getCategorical() {
        return categorical;
      }

      /**
       * Description of the categorical values of this feature.
       * The value set may be {@code null}.
       */
      public Features setCategorical(Categorical categorical) {
        this.categorical = categorical;
        return this;
      }

      /**
       * The feature index.
       * The value returned may be {@code null}.
       */
      public Long getIndex() {
        return index;
      }

      /**
       * The feature index.
       * The value set may be {@code null}.
       */
      public Features setIndex(Long index) {
        this.index = index;
        return this;
      }

      /**
       * Description of the numeric values of this feature.
       * The value returned may be {@code null}.
       */
      public Numeric getNumeric() {
        return numeric;
      }

      /**
       * Description of the numeric values of this feature.
       * The value set may be {@code null}.
       */
      public Features setNumeric(Numeric numeric) {
        this.numeric = numeric;
        return this;
      }

      /**
       * Description of multiple-word text values of this feature.
       * The value returned may be {@code null}.
       */
      public Text getText() {
        return text;
      }

      /**
       * Description of multiple-word text values of this feature.
       * The value set may be {@code null}.
       */
      public Features setText(Text text) {
        this.text = text;
        return this;
      }

      /**
       * Description of the categorical values of this feature.
       */
      public static final class Categorical extends GenericJson {

        /**
         * Number of categorical values for this feature in the data.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key @JsonString
        private Long count;

        /**
         * List of all the categories for this feature in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private java.util.List<Values> values;

        static {
          // hack to force ProGuard to consider Values used, since otherwise it would be stripped out
          // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
          com.google.api.client.util.Data.nullOf(Values.class);
        }

        /**
         * Number of categorical values for this feature in the data.
         * The value returned may be {@code null}.
         */
        public Long getCount() {
          return count;
        }

        /**
         * Number of categorical values for this feature in the data.
         * The value set may be {@code null}.
         */
        public Categorical setCount(Long count) {
          this.count = count;
          return this;
        }

        /**
         * List of all the categories for this feature in the data set.
         * The value returned may be {@code null}.
         */
        public java.util.List<Values> getValues() {
          return values;
        }

        /**
         * List of all the categories for this feature in the data set.
         * The value set may be {@code null}.
         */
        public Categorical setValues(java.util.List<Values> values) {
          this.values = values;
          return this;
        }

        /**
         * Model definition for AnalyzeDataDescriptionFeaturesCategoricalValues.
         */
        public static final class Values extends GenericJson {

          /**
           * Number of times this feature had this value.
           * The value may be {@code null}.
           */
          @com.google.api.client.util.Key @JsonString
          private Long count;

          /**
           * The category name.
           * The value may be {@code null}.
           */
          @com.google.api.client.util.Key
          private String value;

          /**
           * Number of times this feature had this value.
           * The value returned may be {@code null}.
           */
          public Long getCount() {
            return count;
          }

          /**
           * Number of times this feature had this value.
           * The value set may be {@code null}.
           */
          public Values setCount(Long count) {
            this.count = count;
            return this;
          }

          /**
           * The category name.
           * The value returned may be {@code null}.
           */
          public String getValue() {
            return value;
          }

          /**
           * The category name.
           * The value set may be {@code null}.
           */
          public Values setValue(String value) {
            this.value = value;
            return this;
          }

        }
      }
      /**
       * Description of the numeric values of this feature.
       */
      public static final class Numeric extends GenericJson {

        /**
         * Number of numeric values for this feature in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key @JsonString
        private Long count;

        /**
         * Mean of the numeric values of this feature in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String mean;

        /**
         * Variance of the numeric values of this feature in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String variance;

        /**
         * Number of numeric values for this feature in the data set.
         * The value returned may be {@code null}.
         */
        public Long getCount() {
          return count;
        }

        /**
         * Number of numeric values for this feature in the data set.
         * The value set may be {@code null}.
         */
        public Numeric setCount(Long count) {
          this.count = count;
          return this;
        }

        /**
         * Mean of the numeric values of this feature in the data set.
         * The value returned may be {@code null}.
         */
        public String getMean() {
          return mean;
        }

        /**
         * Mean of the numeric values of this feature in the data set.
         * The value set may be {@code null}.
         */
        public Numeric setMean(String mean) {
          this.mean = mean;
          return this;
        }

        /**
         * Variance of the numeric values of this feature in the data set.
         * The value returned may be {@code null}.
         */
        public String getVariance() {
          return variance;
        }

        /**
         * Variance of the numeric values of this feature in the data set.
         * The value set may be {@code null}.
         */
        public Numeric setVariance(String variance) {
          this.variance = variance;
          return this;
        }

      }
      /**
       * Description of multiple-word text values of this feature.
       */
      public static final class Text extends GenericJson {

        /**
         * Number of multiple-word text values for this feature.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key @JsonString
        private Long count;

        /**
         * Number of multiple-word text values for this feature.
         * The value returned may be {@code null}.
         */
        public Long getCount() {
          return count;
        }

        /**
         * Number of multiple-word text values for this feature.
         * The value set may be {@code null}.
         */
        public Text setCount(Long count) {
          this.count = count;
          return this;
        }

      }
    }
    /**
     * Description of the output value or label.
     */
    public static final class OutputFeature extends GenericJson {

      /**
       * Description of the output values in the data set.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private Numeric numeric;

      /**
       * Description of the output labels in the data set.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private java.util.List<Text> text;

      static {
        // hack to force ProGuard to consider Text used, since otherwise it would be stripped out
        // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
        com.google.api.client.util.Data.nullOf(Text.class);
      }

      /**
       * Description of the output values in the data set.
       * The value returned may be {@code null}.
       */
      public Numeric getNumeric() {
        return numeric;
      }

      /**
       * Description of the output values in the data set.
       * The value set may be {@code null}.
       */
      public OutputFeature setNumeric(Numeric numeric) {
        this.numeric = numeric;
        return this;
      }

      /**
       * Description of the output labels in the data set.
       * The value returned may be {@code null}.
       */
      public java.util.List<Text> getText() {
        return text;
      }

      /**
       * Description of the output labels in the data set.
       * The value set may be {@code null}.
       */
      public OutputFeature setText(java.util.List<Text> text) {
        this.text = text;
        return this;
      }

      /**
       * Description of the output values in the data set.
       */
      public static final class Numeric extends GenericJson {

        /**
         * Number of numeric output values in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key @JsonString
        private Long count;

        /**
         * Mean of the output values in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String mean;

        /**
         * Variance of the output values in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String variance;

        /**
         * Number of numeric output values in the data set.
         * The value returned may be {@code null}.
         */
        public Long getCount() {
          return count;
        }

        /**
         * Number of numeric output values in the data set.
         * The value set may be {@code null}.
         */
        public Numeric setCount(Long count) {
          this.count = count;
          return this;
        }

        /**
         * Mean of the output values in the data set.
         * The value returned may be {@code null}.
         */
        public String getMean() {
          return mean;
        }

        /**
         * Mean of the output values in the data set.
         * The value set may be {@code null}.
         */
        public Numeric setMean(String mean) {
          this.mean = mean;
          return this;
        }

        /**
         * Variance of the output values in the data set.
         * The value returned may be {@code null}.
         */
        public String getVariance() {
          return variance;
        }

        /**
         * Variance of the output values in the data set.
         * The value set may be {@code null}.
         */
        public Numeric setVariance(String variance) {
          this.variance = variance;
          return this;
        }

      }
      /**
       * Model definition for AnalyzeDataDescriptionOutputFeatureText.
       */
      public static final class Text extends GenericJson {

        /**
         * Number of times the output label occurred in the data set.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key @JsonString
        private Long count;

        /**
         * The output label.
         * The value may be {@code null}.
         */
        @com.google.api.client.util.Key
        private String value;

        /**
         * Number of times the output label occurred in the data set.
         * The value returned may be {@code null}.
         */
        public Long getCount() {
          return count;
        }

        /**
         * Number of times the output label occurred in the data set.
         * The value set may be {@code null}.
         */
        public Text setCount(Long count) {
          this.count = count;
          return this;
        }

        /**
         * The output label.
         * The value returned may be {@code null}.
         */
        public String getValue() {
          return value;
        }

        /**
         * The output label.
         * The value set may be {@code null}.
         */
        public Text setValue(String value) {
          this.value = value;
          return this;
        }

      }
    }
  }

  /**
   * Description of the model.
   */
  public static final class ModelDescription extends GenericJson {

    /**
     * An output confusion matrix. This shows an estimate for how this model will do in predictions.
     * This is first indexed by the true class label. For each true class label, this provides a pair
     * {predicted_label, count}, where count is the estimated number of times the model will predict
     * the predicted label given the true label. Will not output if more then 100 classes (Categorical
     * models only).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.Map<String, java.util.Map<String, String>> confusionMatrix;

    /**
     * A list of the confusion matrix row totals.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private java.util.Map<String, String> confusionMatrixRowTotals;

    /**
     * Basic information about the model.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Insert2 modelinfo;

    /**
     * An output confusion matrix. This shows an estimate for how this model will do in predictions.
     * This is first indexed by the true class label. For each true class label, this provides a pair
     * {predicted_label, count}, where count is the estimated number of times the model will predict
     * the predicted label given the true label. Will not output if more then 100 classes (Categorical
     * models only).
     * The value returned may be {@code null}.
     */
    public java.util.Map<String, java.util.Map<String, String>> getConfusionMatrix() {
      return confusionMatrix;
    }

    /**
     * An output confusion matrix. This shows an estimate for how this model will do in predictions.
     * This is first indexed by the true class label. For each true class label, this provides a pair
     * {predicted_label, count}, where count is the estimated number of times the model will predict
     * the predicted label given the true label. Will not output if more then 100 classes (Categorical
     * models only).
     * The value set may be {@code null}.
     */
    public ModelDescription setConfusionMatrix(java.util.Map<String, java.util.Map<String, String>> confusionMatrix) {
      this.confusionMatrix = confusionMatrix;
      return this;
    }

    /**
     * A list of the confusion matrix row totals.
     * The value returned may be {@code null}.
     */
    public java.util.Map<String, String> getConfusionMatrixRowTotals() {
      return confusionMatrixRowTotals;
    }

    /**
     * A list of the confusion matrix row totals.
     * The value set may be {@code null}.
     */
    public ModelDescription setConfusionMatrixRowTotals(java.util.Map<String, String> confusionMatrixRowTotals) {
      this.confusionMatrixRowTotals = confusionMatrixRowTotals;
      return this;
    }

    /**
     * Basic information about the model.
     * The value returned may be {@code null}.
     */
    public Insert2 getModelinfo() {
      return modelinfo;
    }

    /**
     * Basic information about the model.
     * The value set may be {@code null}.
     */
    public ModelDescription setModelinfo(Insert2 modelinfo) {
      this.modelinfo = modelinfo;
      return this;
    }

  }

}
